@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/pkg/bin/python3.10
 #
 #===- clang-tidy-diff.py - ClangTidy Diff Checker -----------*- python -*--===#
 #
@@ -44,7 +44,7 @@ except ImportError:
 is_py2 = sys.version[0] == '2'
 
 if is_py2:
-    import queue as queue
+    import Queue as queue
 else:
     import queue as queue
 
@@ -258,7 +258,7 @@ def main():
   task_queue.join()
 
   if yaml and args.export_fixes:
-    print(('Writing fixes to ' + args.export_fixes + ' ...'))
+    print('Writing fixes to ' + args.export_fixes + ' ...')
     try:
       merge_replacement_files(tmpdir, args.export_fixes)
     except:
