@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.10
+#!/usr/pkg/bin/python3.10
 #
 #=- run-find-all-symbols.py - Parallel find-all-symbols runner -*- python  -*-=#
 #
@@ -26,7 +26,7 @@ import argparse
 import json
 import multiprocessing
 import os
-import queue
+import Queue
 import shutil
 import subprocess
 import sys
@@ -39,7 +39,7 @@ def find_compilation_database(path):
   result = './'
   while not os.path.isfile(os.path.join(result, path)):
     if os.path.realpath(result) == '/':
-      print('Error: could not find compilation database.')
+      print 'Error: could not find compilation database.'
       sys.exit(1)
     result += '../'
   return os.path.realpath(result)
@@ -49,7 +49,7 @@ def MergeSymbols(directory, args):
   """Merge all symbol files (yaml) in a given directory into a single file."""
   invocation = [args.binary, '-merge-dir='+directory, args.saving_path]
   subprocess.call(invocation)
-  print('Merge is finished. Saving results in ' + args.saving_path)
+  print 'Merge is finished. Saving results in ' + args.saving_path
 
 
 def run_find_all_symbols(args, tmpdir, build_path, queue):
@@ -98,7 +98,7 @@ def main():
 
   try:
     # Spin up a bunch of tidy-launching threads.
-    queue = queue.Queue(max_task)
+    queue = Queue.Queue(max_task)
     for _ in range(max_task):
       t = threading.Thread(target=run_find_all_symbols,
                            args=(args, tmpdir, build_path, queue))
@@ -118,7 +118,7 @@ def main():
   except KeyboardInterrupt:
     # This is a sad hack. Unfortunately subprocess goes
     # bonkers with ctrl-c and we start forking merrily.
-    print('\nCtrl-C detected, goodbye.')
+    print '\nCtrl-C detected, goodbye.'
     os.kill(0, 9)
 
 
